@@ -5,13 +5,15 @@ import inspect
 import os
 import sys
 
-__version__ = '0.0.5'
+__version__ = '0.0.11'
 
 real_path = os.path.dirname(os.path.abspath(__file__)).replace("\\","/")
 sys.path.append(real_path)
 
 try:
-    from TAD_Library import *
+    from .Common import *
+    from .TT_Function import TT as TT
+    from .TCP_Packet_Lib import *
 except ImportError as e:
     print(e,"import fail")
 
